<p align="center">
    <strong>Python SDK for UP42</strong>
    <br/>
    UP42 transforms how organizations order, access, and analyze EO data.
</p>

![](docs/assets/github-banner-3.jpg)

<p align="center">
    <a href="https://pypi.org/project/up42-py/" title="up42-py on pypi"><img src="https://img.shields.io/pypi/v/up42-py?color=brightgreen"></a>
    <img src="https://sonarcloud.io/api/project_badges/measure?project=up42_up42-py&metric=coverage">
</p>


## Installation

```bash
pip install up42-py
```
```bash
conda install -c conda-forge up42-py
```

## Documentation

- [Reference](https://docs.up42.com/sdk/reference)
- [Release notes](https://docs.up42.com/sdk/release-notes)
- [Authentication](https://docs.up42.com/sdk/authentication)
- [Quick start](https://docs.up42.com/sdk/quick-start)

## Support

For issues or suggestions, [contact support](https://up42.com/company/contact-support).
